@@ -65,140 +65,6 @@ from rapida.utils.rapida_header import (
     HEADER_LONGITUDE,
 )
 
-# from rapida.clients.document import IndexKnowledgeDocument
-# from rapida.clients.marketplace import GetAllDeployment
-# from rapida.clients.invoke import Invoke
-# from rapida.clients.auth import (
-#     AuthenticateUser,
-#     AuthorizeUser,
-#     RegisterUser,
-#     VerifyToken,
-#     ForgotPassword,
-#     CreatePassword,
-#     GetUser,
-#     UpdateUser,
-#     GetAllUser,
-#     Google,
-#     Linkedin,
-#     Github,
-# )
-# from rapida.clients.provider import GetAllProvider, GetAllToolProvider
-# from rapida.clients.index import (
-#     WithPlatform,
-#     WithAuthContext,
-#     get_client_info,
-#     WithClientContext,
-# )
-# from rapida.clients.connect import (
-#     GeneralConnect,
-#     KnowledgeConnect,
-#     ActionConnect,
-#     GetConnectorFiles,
-# )
-# from rapida.clients.organization import (
-#     CreateOrganization,
-#     UpdateOrganization,
-#     GetOrganization,
-# )
-# from rapida.clients.assistant import (
-#     GetAllAssistant,
-#     UpdateAssistantVersion,
-#     GetAllAssistantProviderModel,
-#     GetAssistant,
-#     CreateAssistantProviderModel,
-#     CreateAssistant,
-#     CreateAssistantTag,
-#     UpdateAssistantDetail,
-#     GetAssistantMessages,
-#     GetMessages,
-#     GetAllAssistantSession,
-#     GetAllAssistantConversationMessage,
-#     GetAllAssistantWebhook,
-#     CreateWebhook,
-#     UpdateWebhook,
-#     GetAssistantWebhook,
-#     DeleteAssistantWebhook,
-#     GetAssistantConversation,
-#     DeleteAssistant,
-#     GetAllAssistantAnalysis,
-#     CreateAnalysis,
-#     UpdateAnalysis,
-#     GetAssistantAnalysis,
-#     DeleteAssistantAnalysis,
-#     GetAllWebhookLog,
-#     GetWebhookLog,
-#     GetAllAssistantTool,
-#     CreateAssistantTool,
-#     UpdateAssistantTool,
-#     GetAssistantTool,
-#     DeleteAssistantTool,
-#     GetAllAssistantKnowledge,
-#     CreateAssistantKnowledge,
-#     UpdateAssistantKnowledge,
-#     GetAssistantKnowledge,
-#     DeleteAssistantKnowledge,
-# )
-# from rapida.clients.deployment import (
-#     CreateAssistantDebuggerDeployment,
-#     GetAssistantDebuggerDeployment,
-#     CreateAssistantApiDeployment,
-#     GetAssistantApiDeployment,
-#     CreateAssistantWebpluginDeployment,
-#     GetAssistantWebpluginDeployment,
-#     CreateAssistantPhoneDeployment,
-#     GetAssistantPhoneDeployment,
-#     CreateAssistantWhatsappDeployment,
-#     GetAssistantWhatsappDeployment,
-# )
-# from rapida.clients.activity import GetActivities, GetActivity
-# from rapida.clients.endpoint import (
-#     GetAllEndpoint,
-#     UpdateEndpointVersion,
-#     GetAllEndpointProviderModel,
-#     GetEndpoint,
-#     CreateEndpointProviderModel,
-#     CreateEndpoint,
-#     CreateEndpointTag,
-#     UpdateEndpointDetail,
-#     CreateEndpointRetryConfiguration,
-#     CreateEndpointCacheConfiguration,
-#     GetAllEndpointLog,
-#     GetEndpointLog,
-# )
-# from rapida.clients.vault import (
-#     CreateProviderKey,
-#     DeleteProviderKey,
-#     AllOrganizationCredential,
-#     CreateToolCredential,
-# )
-# from rapida.clients.talk import (
-#     AssistantTalk,
-#     CreateMessageMetric,
-#     CreateConversationMetric,
-#     GetAllAssistantConversation,
-# )
-# from rapida.clients.knowledge import (
-#     CreateKnowledge,
-#     GetKnowledgeBase,
-#     GetAllKnowledgeBases,
-#     CreateKnowledgeDocument,
-#     GetAllKnowledgeDocument,
-#     GetAllKnowledgeDocumentSegment,
-#     CreateKnowledgeTag,
-#     UpdateKnowledgeDetail,
-#     DeleteKnowledgeDocumentSegment,
-#     UpdateKnowledgeDocumentSegment,
-# )
-# from rapida.clients.project import (
-#     AddUsersToProject,
-#     CreateProject,
-#     UpdateProject,
-#     GetAllProject,
-#     GetProject,
-#     DeleteProject,
-#     GetAllProjectCredential,
-#     CreateProjectCredential,
-# )
 from rapida.clients.call import create_phone_call, create_bulk_phone_call
 from rapida.clients.assistant import (
     get_assistant,
@@ -226,6 +92,7 @@ from rapida.clients.endpoint import (
 
 from rapida.clients.invoke import invoke
 
+
 # # Protobuf imports
 from rapida.clients.protos.assistant_knowledge_pb2 import (
     AssistantKnowledge,
@@ -398,6 +265,8 @@ from rapida.clients.protos.common_pb2 import (
     GetAllAssistantConversationResponse,
     GetAllConversationMessageRequest,
     GetAllConversationMessageResponse,
+    AssistantConversationMessageTextContent,
+    AssistantConversationMessageAudioContent,
 )
 from rapida.clients.protos.assistant_webhook_pb2 import (
     AssistantWebhook,
@@ -540,6 +409,8 @@ from rapida.clients.protos.assistant_api_pb2 import (
     GetAssistantConversationResponse,
 )
 
+from rapida.clients.protos.talk_api_pb2_grpc import AgentKitStub, AgentKit, AgentKitServicer, add_AgentKitServicer_to_server
+
 __all__ = [
     "Any",
     "RapidaSource",
@@ -601,120 +472,6 @@ __all__ = [
     "invoke",
     "get_assistant_analysis",
     "get_all_assistant_analysis",
-    #     "IndexKnowledgeDocument",
-    #     "GetAllDeployment",
-    #     "Invoke",
-    #     "AuthenticateUser",
-    #     "AuthorizeUser",
-    #     "RegisterUser",
-    #     "VerifyToken",
-    #     "ForgotPassword",
-    #     "CreatePassword",
-    #     "GetUser",
-    #     "UpdateUser",
-    #     "GetAllUser",
-    #     "Google",
-    #     "Linkedin",
-    #     "Github",
-    #     "GetAllProvider",
-    #     "GetAllToolProvider",
-    #     "WithPlatform",
-    #     "WithAuthContext",
-    #     "get_client_info",
-    #     "WithClientContext",
-    #     "GeneralConnect",
-    #     "KnowledgeConnect",
-    #     "ActionConnect",
-    #     "GetConnectorFiles",
-    #     "CreateOrganization",
-    #     "UpdateOrganization",
-    #     "GetOrganization",
-    #     "GetAllAssistant",
-    #     "UpdateAssistantVersion",
-    #     "GetAllAssistantProviderModel",
-    #     "GetAssistant",
-    #     "CreateAssistantProviderModel",
-    #     "CreateAssistant",
-    #     "CreateAssistantTag",
-    #     "UpdateAssistantDetail",
-    #     "GetAssistantMessages",
-    #     "GetMessages",
-    #     "GetAllAssistantSession",
-    #     "GetAllAssistantConversationMessage",
-    #     "GetAllAssistantWebhook",
-    #     "CreateWebhook",
-    #     "UpdateWebhook",
-    #     "GetAssistantWebhook",
-    #     "DeleteAssistantWebhook",
-    #     "GetAssistantConversation",
-    #     "DeleteAssistant",
-    #     "GetAllAssistantAnalysis",
-    #     "CreateAnalysis",
-    #     "UpdateAnalysis",
-    #     "GetAssistantAnalysis",
-    #     "DeleteAssistantAnalysis",
-    #     "GetAllWebhookLog",
-    #     "GetWebhookLog",
-    #     "GetAllAssistantTool",
-    #     "CreateAssistantTool",
-    #     "UpdateAssistantTool",
-    #     "GetAssistantTool",
-    #     "DeleteAssistantTool",
-    #     "GetAllAssistantKnowledge",
-    #     "CreateAssistantKnowledge",
-    #     "UpdateAssistantKnowledge",
-    #     "GetAssistantKnowledge",
-    #     "DeleteAssistantKnowledge",
-    #     "CreateAssistantDebuggerDeployment",
-    #     "GetAssistantDebuggerDeployment",
-    #     "CreateAssistantApiDeployment",
-    #     "GetAssistantApiDeployment",
-    #     "CreateAssistantWebpluginDeployment",
-    #     "GetAssistantWebpluginDeployment",
-    #     "CreateAssistantPhoneDeployment",
-    #     "GetAssistantPhoneDeployment",
-    #     "CreateAssistantWhatsappDeployment",
-    #     "GetAssistantWhatsappDeployment",
-    #     "GetActivities",
-    #     "GetActivity",
-    #     "GetAllEndpoint",
-    #     "UpdateEndpointVersion",
-    #     "GetAllEndpointProviderModel",
-    #     "GetEndpoint",
-    #     "CreateEndpointProviderModel",
-    #     "CreateEndpoint",
-    #     "CreateEndpointTag",
-    #     "UpdateEndpointDetail",
-    #     "CreateEndpointRetryConfiguration",
-    #     "CreateEndpointCacheConfiguration",
-    #     "GetAllEndpointLog",
-    #     "GetEndpointLog",
-    #     "CreateProviderKey",
-    #     "DeleteProviderKey",
-    #     "AllOrganizationCredential",
-    #     "CreateToolCredential",
-    #     "AssistantTalk",
-    #     "CreateMessageMetric",
-    #     "CreateConversationMetric",
-    #     "GetAllAssistantConversation",
-    #     "CreateKnowledge",
-    #     "GetKnowledgeBase",
-    #     "GetAllKnowledgeBases",
-    #     "CreateKnowledgeDocument",
-    #     "GetAllKnowledgeDocument",
-    #     "GetAllKnowledgeDocumentSegment",
-    #     "CreateKnowledgeTag",
-    #     "UpdateKnowledgeDetail",
-    #     "DeleteKnowledgeDocumentSegment",
-    #     "UpdateKnowledgeDocumentSegment",
-    #     "AddUsersToProject",
-    #     "CreateProject",
-    #     "UpdateProject",
-    #     "GetAllProject",
-    #     "GetProject",
-    #     "DeleteProject",
-    #     "GetAllProjectCredential",
-    #     "CreateProjectCredential",
     "create_phone_call",
     "create_bulk_phone_call",
     # Protobuf classes
@@ -992,4 +749,10 @@ __all__ = [
     "UpdateAssistantDetailRequest",
     "GetAssistantConversationRequest",
     "GetAssistantConversationResponse",
+    "AssistantConversationMessageTextContent",
+    "AssistantConversationMessageAudioContent",
+    "AgentKitStub",
+    "AgentKit",
+    "AgentKitServicer",
+    "add_AgentKitServicer_to_server",
 ]
